video_player_harmonyos library

Classes

DataSource
Description of the data source used to create an instance of the video player.
DurationRange
Describes a discrete segment of time within a video using a start and end Duration.
VideoAudioTrack
Represents an audio track in a video with its metadata.
VideoCreationOptions
VideoCreationOptions contains creation options for a video player.
VideoEvent
Event emitted from the platform implementation.
VideoPlayerHarmonyOS
An OHOS implementation of VideoPlayerPlatform that uses the Pigeon-generated OhosVideoPlayerApi.
VideoPlayerOptions
VideoPlayerOptions can be optionally used to set additional player settings
VideoPlayerPlatform
The interface that implementations of video_player must implement.
VideoPlayerWebOptions
VideoPlayerWebOptions can be optionally used to set additional web settings
VideoPlayerWebOptionsControls
VideoPlayerWebOptions can be used to set how control options are displayed
VideoTrack
Represents a video track (quality variant) in a video with its metadata.
VideoViewOptions
VideoViewOptions contains configuration options for a video view.

Enums

DataSourceType
The way in which the video was originally loaded.
VideoEventType
Type of the event.
VideoFormat
The file format of the given video.
VideoViewType
The type of video view to be used.