VideoEventType enum
Type of the event.
Emitted by the platform implementation when the video is initialized or completed or to communicate buffering events or play state changed.
Values
- initialized → const VideoEventType
-
The video has been initialized.
A maximum of one event of this type may be emitted per instance.
- completed → const VideoEventType
-
The playback has ended.
- bufferingUpdate → const VideoEventType
-
Updated information on the buffering state.
- bufferingStart → const VideoEventType
-
The video started to buffer.
- bufferingEnd → const VideoEventType
-
The video stopped to buffer.
- isPlayingStateUpdate → const VideoEventType
-
The playback state of the video has changed.
This event is fired when the video starts or pauses due to user actions or phone calls, or other app media such as music players.
- unknown → const VideoEventType
-
An unknown event has been received.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VideoEventType> - A constant List of the values in this enum, in order of their declaration.