VideoViewOptions class

VideoViewOptions contains configuration options for a video view.

Annotations

Constructors

VideoViewOptions({required int playerId})
Constructs an instance of VideoViewOptions.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
playerId int
The identifier of the video player.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited